==> de.flapdoodle.os-1.4.5-sources.jar: de/flapdoodle/os/linux/DebianVersion.java <==
/*
 * Copyright (C) 2020
 *   Michael Mosmann <michael@mosmann.de>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.os.linux;

import de.flapdoodle.os.Version;
import de.flapdoodle.os.common.HasPecularities;
import de.flapdoodle.os.common.OneOf;
import de.flapdoodle.os.common.Peculiarity;

import java.util.List;

public enum DebianVersion implements Version {
    DEBIAN_9(OsReleaseFiles.osReleaseFileVersionMatches("9")),
    DEBIAN_10(OsReleaseFiles.osReleaseFileVersionMatches("10")),
    DEBIAN_11(OsReleaseFiles.osReleaseFileVersionMatches("11")),
    DEBIAN_12(OneOf.of(
      OsReleaseFiles.osReleaseFileVersionMatches("12"),
      OsReleaseFiles.osReleaseFileVersionCodeNameIs("bookworm")
    ));

    private final List<Peculiarity> peculiarities;

    DebianVersion(final Peculiarity... peculiarities) {
        this.peculiarities = HasPecularities.asList(peculiarities);
    }

    @Override
    public List<Peculiarity> pecularities() {
        return peculiarities;
    }
}

==> de.flapdoodle.os-1.7.0-sources.jar: de/flapdoodle/os/linux/DebianVersion.java <==
/*
 * Copyright (C) 2020
 *   Michael Mosmann <michael@mosmann.de>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.os.linux;

import de.flapdoodle.os.Version;
import de.flapdoodle.os.common.HasPecularities;
import de.flapdoodle.os.common.OneOf;
import de.flapdoodle.os.common.Peculiarity;

import java.util.List;

public enum DebianVersion implements Version {
    DEBIAN_9(OsReleaseFiles.osReleaseFileVersionMatches("9")),
    DEBIAN_10(OsReleaseFiles.osReleaseFileVersionMatches("10")),
    DEBIAN_11(OsReleaseFiles.osReleaseFileVersionMatches("11")),
    DEBIAN_12(OneOf.of(
      OsReleaseFiles.osReleaseFileVersionMatches("12"),
      OsReleaseFiles.osReleaseFileVersionCodeNameIs("bookworm")
    )),
    DEBIAN_13(OneOf.of(
      OsReleaseFiles.osReleaseFileVersionMatches("13"),
      OsReleaseFiles.osReleaseFileVersionCodeNameIs("trixie")
    ));

    private final List<Peculiarity> peculiarities;

    DebianVersion(final Peculiarity... peculiarities) {
        this.peculiarities = HasPecularities.asList(peculiarities);
    }

    @Override
    public List<Peculiarity> pecularities() {
        return peculiarities;
    }
}
